<?php $TRANSLATIONS = array(
"Save" => "Сохранить",
"Search:" => "Найти:",
"Close" => "Закрыть",
"Next" => "Следующий",
"Clear" => "Очистить",
"Saving..." => "Сохранение...",
"Failed to save file" => "Не удалось сохранить файл",
"An error occurred!" => "Произошла ошибка!",
"There were unsaved changes, click here to go back" => "Есть несохранённые изменения, нажмите сюда для возврата назад"
);
